#
# spec file for package python-keyrings.alt
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define keyring_ver 18.0.0
%{?sle15_python_module_pythons}
Name:           python-keyrings.alt
Version:        4.2.0
Release:        2.4
Summary:        Alternate keyring implementations
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jaraco/keyrings.alt
Source:         https://files.pythonhosted.org/packages/source/k/keyrings.alt/keyrings.alt-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module toml}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-jaraco.classes
Requires:       python-pycryptodomex
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pycryptodome}
BuildRequires:  %{python_module fs >= 0.5}
BuildRequires:  %{python_module gobject}
BuildRequires:  %{python_module keyring >= 20}
BuildRequires:  %{python_module pycryptodomex}
BuildRequires:  %{python_module pycryptodomex}
BuildRequires:  %{python_module pytest >= 3.5}
BuildRequires:  typelib(GnomeKeyring)
# /SECTION
%python_subpackages

%description
Alternate keyring backend implementations for use with the
keyring package.

%prep
%setup -q -n keyrings.alt-%{version}
sed -i -e 's/--flake8//' -e 's/--black//' -e 's/--cov//' pytest.ini

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Thu Jul  6 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 4.2.0:
  * #46: EncryptedFileKeyring now supports both pycryptodome and
  * pycryptodomex (preferring the latter).
  * Updated to work with keyring 23.9+ (no longer depending on
    properties module).
  * Refresh package metadata.
  * Enrolled with Tidelift.
  * #44: Bump upper bound on pyfs.
  * Refresh package metadata.
* Thu Dec 17 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 4.0.2
  * #43: Tests are no longer included in the install.
- 4.0.1
  * Package refresh and minor cleanup.
- 4.0.0
  * #41: Instead of PyCrypto or PyCryptodome, the encrypting
    backend now relies on PyCryptodomex.
- 3.5.2
  * 39: Replace use of deprecated base64.encode/decodestring with
    encode/decodebytes.
- 3.5.1
  * #38: Fixed test suite to work with pytest-based fixtures.
  * Refresh package metadata.
- 3.5.0
  * #33: Rely on keyring.testing (keyring 20) for tests.
- Python 2 is not supported since 3.3.0, skip and remove
  unresolvable backports requirement
* Thu Apr 16 2020 pgajdos@suse.com
- version update to 3.4.0
  * In tests, pin keyring major version.
  * Drop support for Python 3.5 and earlier.
  * In tests, rely on pycryptodome instead of pycrypto for improved
    compatibility.
  * In tests, rely on pytest instead of unittest.
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Remove the test isolation until upstream issue is fixed properly:
  * https://github.com/jaraco/keyrings.alt/issues/33
* Tue Feb 26 2019 John Vandenberg <jayvdb@gmail.com>
- Remove unnecessary build dependencies like tox, flake8 and pytest-sugar
- Activate test suite, and isolate it from python-keyring's test suite
- Update to v3.1.1
  * Trap AttributeError in Gnome backend as in some environments
    it seems that will happen.
  * Fix issue where a backslash in the service name would cause
    errors on Registry backend on Windows.
* Tue Nov  7 2017 toddrme2178@gmail.com
- initial version for v3.1
